@@ -17,7 +17,6 @@ my $Time_HiRes_avail;
 BEGIN {
     $Time_HiRes_avail = 0;
     $Time_HiRes_avail = eval 'use Time::HiRes qw(time);1';
-#    eval 'use Time::HiRes qw(time);$Time_HiRes_avail=1';  ## no critic (StringyEval)
 }
 
 
@@ -41,7 +40,7 @@ BEGIN {
 # compile Devel::DumpTrace::Const AFTER the environment is processed
 use Devel::DumpTrace::Const;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 our $ARRAY_ELEM_SEPARATOR = ',';
 our $HASH_ENTRY_SEPARATOR = ';';
 our $HASH_PAIR_SEPARATOR = '=>';
@@ -535,15 +534,13 @@ sub hash_repr {
 	return "$hashref";
     }
 
-
-    if (tied(%{$hashref})
-	&& @keys == 0
-	&& ref(tied %{$hashref}) eq 'Devel::DumpTrace::CachedDisplayedHash') {
+    if (@keys == 0 &&
+        Devel::DumpTrace::CachedDisplayedHash->is($hashref)) {
 
 	my $result = (tied %{$hashref})->get_cache($cache_key);
 	if (defined $result) {
 	    return $ref . join $HASH_ENTRY_SEPARATOR,
-	    map { join $HASH_PAIR_SEPARATOR, @{$_} } _condsort(@{$result});
+	        map { join $HASH_PAIR_SEPARATOR, @{$_} } _condsort(@{$result});
 	}
 	$hash = (tied %{$hashref})->{PHASH};
     } elsif (!tied(%{$hashref}) 
@@ -553,8 +550,9 @@ sub hash_repr {
 	     # use safekeys in case this DB hook is inside an `each` iterator
 	     && 100 < scalar safekeys %$hashref) {
 
-	tie %{$hashref}, 'Devel::DumpTrace::CachedDisplayedHash', %{$hashref};
-	$hash = (tied %{$hashref})->{PHASH};
+	my $cdh = tie %{$hashref}, 'Devel::DumpTrace::CachedDisplayedHash',
+                      %{$hashref};
+        $hash = $cdh->{PHASH};
     } else {
 	# Hash::SafeKeysLLsafekeys will not reset an active `each` iterator
 	$hash = { map { dump_scalar($_) => dump_scalar($hashref->{$_}) } 
@@ -574,8 +572,7 @@ sub hash_repr {
 	@r = map { [ $_ => $hash->{$_} ] } _condsort(safekeys %$hash);
     }
 
-    if (@keys == 0 && tied(%{$hashref})
-	&& ref(tied %{$hashref}) eq 'Devel::DumpTrace::CachedDisplayedHash') {
+    if (@keys == 0 && Devel::DumpTrace::CachedDisplayedHash->is($hashref)) {
 	(tied %{$hashref})->store_cache($cache_key, \@r);
     }
 
@@ -624,9 +621,8 @@ sub array_repr {
     # see if we can avoid some expensive calls
     # to  Text::Shorten::shorten_array .
 
-    if (@keys==0
-	&& tied @{$arrayref}
-	&& ref(tied @{$arrayref}) eq 'Devel::DumpTrace::CachedDisplayedArray') {
+    if (@keys == 0
+        && Devel::DumpTrace::CachedDisplayedArray->is($arrayref)) {
 
 	my $result = (tied @{$arrayref})->get_cache($cache_key);
 	if (defined $result) {
@@ -634,8 +630,6 @@ sub array_repr {
 	}
 	$array = (tied @{$arrayref})->{PARRAY};
     } elsif (@keys==0 && !tied(@{$arrayref}) && 100 < scalar @{$arrayref}) {
-	use Devel::DumpTrace::CachedDisplayedArray;
-
 	eval {
 	    tie @{$arrayref}, 'Devel::DumpTrace::CachedDisplayedArray',
 	    	@{$arrayref};
@@ -654,9 +648,8 @@ sub array_repr {
     } else {
 	@r = @{$array};
     }
-    if (@keys==0
-	&& tied(@{$arrayref})
-	&& ref(tied @{$arrayref}) eq 'Devel::DumpTrace::CachedDisplayedArray') {
+    if (@keys == 0
+        && Devel::DumpTrace::CachedDisplayedArray->is($arrayref)) {
 	(tied @{$arrayref})->store_cache($cache_key, \@r);
     }
     return $ref . join $ARRAY_ELEM_SEPARATOR, @r;
@@ -1046,7 +1039,7 @@ Devel::DumpTrace - Evaluate and print out each line before it is executed.
 
 =head1 VERSION
 
-0.18
+0.19
 
 =head1 SYNOPSIS
 
@@ -1111,7 +1104,8 @@ See C<$Devel::DumpTrace::TRACE> under the L</"VARIABLES"> section
 for more details about the different levels of verbosity.
 
 This distribution comes with both a basic parser and a
-L<PPI-based parser|Devel::DumpTrace::PPI>. If the L<PPI|PPI>
+L<PPI-based parser|Devel::DumpTrace::PPI> (which relies on L<PPI>
+to understand your source code). If the L<PPI|PPI>
 module is installed on your system, then this module will automatically
 use the PPI-based parser to analyze the traced code. You can
 force this module to use the basic parser by running with the
@@ -1121,16 +1115,13 @@ environment variable:
     # use PPI if available, otherwise use basic parser
     $ perl -d:DumpTrace program.pl
 
-    # fails if PPI is not available
+    # use PPI, fail if it is not available
     $ perl -d:DumpTrace::PPI program.pl
 
     # always uses basic parser
     $ perl -d:DumpTrace::noPPI program.pl
     $ DUMPTRACE_NOPPI=1 perl -d:DumpTrace program.pl
 
-There is also a L<Devel::DumpTrace::PPI|Devel::DumpTrace::PPI> module in this
-distribution which relies on L<PPI|PPI> to understand the source code.
-
 See the L</"BUGS AND LIMITATIONS"> section for important, er, limitations
 of this module, especially for the basic parser.
 
@@ -1410,6 +1401,10 @@ is equivalent to the longer
 
     DUMPTRACE_PID=1 DUMPTRACE_FH=trace.out DUMPTRACE_EXCL=My::Module
 
+=cut
+
+Documented in Devel/DumpTrace/PPI.pm:  $ENV{DUMPTRACE_DUMB_ABBREV}
+
 =head1 INCOMPATIBILITIES
 
 None known.
@@ -1420,7 +1415,7 @@ Nothing is or can be exported from this module.
 
 =head1 DIAGNOSTICS
 
-All output from this program is for diagnostics.
+All output from this module is for diagnostics.
 
 =head1 DEPENDENCIES
 
@@ -1476,6 +1471,15 @@ some of the issues described in L<perlfunc/"caller">:
 That is, the displayed value of C<@_> inside a subroutine may be
 corrupted. Different versions of Perl may have different behavior.
 
+=head3 C<grep EXPR,LIST> and C<map EXPR,LIST> statements
+
+C<grep EXPR,LIST> and C<map EXPR,LIST> constructions are evaluated
+a single time, after the entier C<LIST> has been evaluated, and this
+module does not let you drill down to how each element of the list
+was evaluated with the given C<EXPR>. The constructions 
+C<grep BLOCK LIST> and C<map BLOCK LIST>, however, will display the
+C<BLOCK> evaluation for each element of the C<LIST>.
+
 =head2 Basic parser limitations
 
 This distribution ships with a L<PPI|PPI>-based parser
@@ -1584,7 +1588,7 @@ Marty O'Brien, E<lt>mob at cpan.orgE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2013 Marty O'Brien.
+Copyright 2010-2015 Marty O'Brien.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
