@@ -2,7 +2,7 @@
 # tied array object that maintains two additional states:
 #   1. a parallel array where all original entries
 #      are run through  &Devel::DumpTrade::dump_scalar
-#   2. a cache of results from  Text::Shorten::shorten_hash
+#   2. a cache of results from  Text::Shorten::shorten_array
 #
 # Calls to  Devel::DumpTrace::array_repr  should not trigger calls
 # to  Text::Shorten::shorten_array  unless the array
@@ -14,7 +14,7 @@ package Devel::DumpTrace::CachedDisplayedArray;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 *dump_scalar = \&Devel::DumpTrace::dump_scalar;
 
@@ -164,4 +164,9 @@ sub get_cache {
   return $self->{CACHE}{$key};
 }
 
+sub is {
+    my ($pkg, $arrayref) = @_;
+    return tied(@$arrayref) && ref(tied(@$arrayref)) eq $pkg;
+}
+
 1;
