@@ -14,7 +14,7 @@ package Devel::DumpTrace::CachedDisplayedHash;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 *dump_scalar = \&Devel::DumpTrace::dump_scalar;
 
@@ -115,4 +115,9 @@ sub get_cache {
   return $self->{CACHE}{$key};
 }
 
+sub is {
+    my ($pkg, $hashref) = @_;
+    return tied(%$hashref) && ref(tied(%$hashref)) eq $pkg;
+}
+
 1;
