@@ -9,15 +9,6 @@ use Carp;
 use strict;
 use warnings;
 
-# functions in this file that override functions in Devel/DumpTrace.pm
-
-*Devel::DumpTrace::get_source = *get_source_PPI;
-*Devel::DumpTrace::evaluate_and_display_line = *evaluate_and_display_line_PPI;
-*Devel::DumpTrace::handle_deferred_output = *handle_deferred_output_PPI;
-
-*evaluate = *Devel::DumpTrace::evaluate;
-*current_position_string = *Devel::DumpTrace::current_position_string;
-
 local $| = 1;
 
 croak "Devel::DumpTrace::PPI may not be used when \$Devel::DumpTrace::NO_PPI ",
@@ -27,7 +18,19 @@ eval {use PPI;
       1}
   or croak "PPI not installed. Can't use Devel::DumpTrace::PPI module";
 
-$Devel::DumpTrace::PPI::VERSION = '0.18';
+
+# functions in this file that override functions in Devel/DumpTrace.pm
+
+*Devel::DumpTrace::get_source = *get_source_PPI;
+*Devel::DumpTrace::evaluate_and_display_line = *evaluate_and_display_line_PPI;
+*Devel::DumpTrace::handle_deferred_output = *handle_deferred_output_PPI;
+
+*evaluate = *Devel::DumpTrace::evaluate;
+*current_position_string = *Devel::DumpTrace::current_position_string;
+
+
+
+$Devel::DumpTrace::PPI::VERSION = '0.19';
 use constant ADD_IMPLICIT_ => 1;
 use constant DECORATE_FOR => 1;
 use constant DECORATE_FOREACH => 1;
@@ -41,7 +44,7 @@ my %implicit_
        lcfirst=>1, length=>1, log=>1, lstat=>1, mkdir=>1, oct=>1, ord=>1,
        pos=>1, print=>1, quotemeta=>1, readlink=>1, readpipe=>1, ref=>1,
        require=>1, reverse=>1, rmdir=>1, sin=>1, split=>1, sqrt=>1, stat=>1,
-       study=>1, uc=>1, ucfirst=>1, unlink=>1, unpack=>1,);
+       study=>1, uc=>1, ucfirst=>1, unlink=>1, unpack=>1, say=>1);
 
 # for persisting the PPI documents we create
 my (%ppi_src, %ppi_doc);
@@ -93,6 +96,11 @@ sub _update_ppi_src_for_file {
     # be included ... ( if ($cond) { $x++ }\n   ===>   don't store  $x++ )
 
     my $statements = $doc->find('PPI::Statement') || [];
+
+    # use  reverse ... ?
+    # then the child statements will be decorated before their parents
+    # if use reverse, then _update_ppi_src_for_element should unshift non push
+
     foreach my $element (@$statements) {
 	my $_line = $element->line_number;
 	__decorate1($element, $file);
@@ -627,16 +635,102 @@ sub __remove_whitespace_and_comments_just_before_end_of_statement {
 
 sub __add_implicit_elements {
     my ($statement) = @_;
+    return if ref($statement) eq 'PPI::Statement::End';
 
     my $e = $statement->{children};
-    __prepend_implicit_to_naked_regexp($e);
-    __append_implicit_to_naked_filetest($e);
-    __append_implicit_to_naked_builtins($e);
-    __insert_implicit_into_default_foreach($e);
+
+    __insert_implicit_NR_into_flipflop($e);
+    __prepend_implicit_topic_to_naked_regexp($e);
+    __append_implicit_topic_to_naked_filetest($e);
+    __append_implicit_topic_to_naked_builtins($e);
+    __insert_implicit_topic_into_default_foreach($e);
+    __prepend_implicit_topic_for_readline_op($e);
+
     return;
 }
 
-sub __prepend_implicit_to_naked_regexp {
+sub __prepend_implicit_topic_for_readline_op {
+    my $e = shift;
+
+    #
+    # while (<$fh>)    means    while ( defined($_=<$fh>) )
+    # until (<$fh>)    means    until ( defined($_=<$fh>) )
+    #
+
+    # also need to capture:
+    #      expression while <$foo>
+    #      while (   <$foo>   )
+    #      while ( readline($foo) )   # 
+
+    # also need to exclude:
+
+    #   while (<$fh> && condition)
+    #   while (condition || <$fh>)
+    #   while ( < $foo > )
+
+    my ($ql,$ql2) = grep ref($_) eq 'PPI::Token::QuoteLike::Readline', @$e;
+    return if $ql2 || !$ql;
+    return if "$ql" !~ /^<[\$\*]?[\w:']+>$/;
+
+    # we expect either:
+    #
+    # 1a. PPI::Token::QuoteLike::Readline as its own statement
+    # 1b. (grand)parent is a PPI::Structure::Condition
+    # 1c. condition is preceded by  while}until (whitespace?)
+    # 1d. condition is followed by  NULL | Structure(;)
+    #
+    # -or-
+    #
+    # 2a. PPI::Token::QuoteLike::Readline in statement with many tokens
+    # 2b. preceded by while|until (whitespace?)
+    # 2c. followed by NULL | Structure(;)
+
+    my $ee = $e;
+    my $ql3 = $ql;
+    my @ref = map { ref } @$e;
+    my @oref = grep { $_ ne 'PPI::Token::Whitespace'
+                   && $_ ne 'PPI::Token::QuoteLike::Readline' } @ref;
+
+    if (@oref == 0) {
+        $ee = $ql->parent;    # PPI::Statement::Expression
+        return if ref($ee) ne 'PPI::Statement::Expression';
+        $ee = $ee->parent;    # PPI::Structure::Condition
+        $ql3 = "$ee";
+        return if ref($ee) ne 'PPI::Structure::Condition';
+        $ee = $ee->parent;    # PPI::Statement
+        return if ref($ee) !~ /^PPI::Statement/;
+        $ee = $ee->{children};
+    }
+
+    for (my $i=0; $i<@$ee; $i++) {
+
+        next if $ee->[$i] ne "$ql" && $ee->[$i] ne $ql3;
+
+        my $j = $i+1;
+        $j++ while $j<@$ee && ref($ee->[$j]) eq 'PPI::Token::Whitespace';
+        return if $j<@$ee && (ref($ee->[$j]) ne 'PPI::Token::Structure' ||
+                              $ee->[$j] ne ';')
+                          && ref($ee->[$j]) ne 'PPI::Structure::Block';
+
+        $j = $i-1;
+        $j-- while $j>=0 && ref($ee->[$j]) eq 'PPI::Token::Whitespace';
+
+        return if $j<0;
+        return if ref($ee->[$j]) ne 'PPI::Token::Word';
+        return if $ee->[$j] ne 'while' && $ee->[$j] ne 'until';
+
+        for (my $k=0; $k<@$e; $k++) {
+            next if ref($e->[$k]) ne 'PPI::Token::QuoteLike::Readline';
+            splice @$e, $k, 0,
+              bless({content=>'$_',_DEFER=>1},'PPI::Token::Magic'),
+              bless({content=>'='}, 'PPI::Token::Operator');
+            last;
+        }
+        last;
+    }
+}
+
+sub __prepend_implicit_topic_to_naked_regexp {
     my $e = shift;
 
     #
@@ -657,7 +751,7 @@ sub __prepend_implicit_to_naked_regexp {
     return;
 }
 
-sub __append_implicit_to_naked_filetest {
+sub __append_implicit_topic_to_naked_filetest {
     my $e = shift;
 
     #
@@ -681,7 +775,7 @@ sub __append_implicit_to_naked_filetest {
     return;
 }
 
-sub __append_implicit_to_naked_builtins {
+sub __append_implicit_topic_to_naked_builtins {
     my $e = shift;
 
     #
@@ -696,12 +790,15 @@ sub __append_implicit_to_naked_builtins {
     for (my $i=0; $i<@$e; $i++) {
 	if (ref($e->[$i]) eq 'PPI::Token::Word' 
 	    && defined $implicit_{"$e->[$i]"}) {
+
 	    my $j = $i + 1;
 	    my $gparent = $e->[$i]->parent && $e->[$i]->parent->parent;
 	    next if $gparent && ref($gparent) eq 'PPI::Structure::Subscript'
 		&& $gparent =~ /^{/;
 	    $j++ while $j <= @$e && ref($e->[$j]) eq 'PPI::Token::Whitespace';
-	    if ($j >= @$e || ref($e->[$j]) eq 'PPI::Token::Structure') {
+	    if ($j >= @$e || ref($e->[$j]) eq 'PPI::Token::Structure'
+                          || (ref($e->[$j]) eq 'PPI::Token::Operator' &&
+                              ($e->[$j] eq '..' || $e->[$j] eq '...'))) {
 		if ($e->[$i] eq 'split') {
 		    # naked  split  is parsed as  split /\s+/, $_
 		    splice @$e, $i+1, 0,
@@ -709,15 +806,10 @@ sub __append_implicit_to_naked_builtins {
 		        bless({content=>'m/\\s+/'},
 			      'PPI::Token::Regexp::Match'),
 		        bless({content=>','}, 'PPI::Token::Operator'),
-			# XXX - why _DEFER => 1 here ???
-#	                bless({content=>'$_', _DEFER => 1}, 
-#		               'PPI::Token::Magic');
 		        bless({content=>'$_'}, 'PPI::Token::Magic');
 		} else {
 		    splice @$e, $i+1, 0,
 		        bless({content=>' '}, 'PPI::Token::Whitespace'),
-#	                bless({content=>'$_', _DEFER => 1}, 
-#			      'PPI::Token::Magic');
 		        bless({content=>'$_'}, 'PPI::Token::Magic');
 		}
 	    }
@@ -726,7 +818,7 @@ sub __append_implicit_to_naked_builtins {
     return;
 }
 
-sub __insert_implicit_into_default_foreach {
+sub __insert_implicit_topic_into_default_foreach {
     my $e = shift;
 
     # for (LIST)        means    for $_ (LIST)
@@ -740,14 +832,56 @@ sub __insert_implicit_into_default_foreach {
 	if ($j < @$e && ref($e->[$j]) eq 'PPI::Structure::List') {
 
 	    splice @$e, $i+1, 0,
-	        bless({content=>' '}, 'PPI::Token::Whitespace'),
-	        bless({content=>'$_', _DEFER => 1}, 'PPI::Token::Magic');
+            bless({content=>' '}, 'PPI::Token::Whitespace'),
+            bless({content=>'$_', _DEFER => 1}, 'PPI::Token::Magic');
 
 	}
     }
     return;
 }
 
+sub __insert_implicit_NR_into_flipflop {
+    #   (m ... n)       means    ($.==m ... $.==n)
+    #   (m .. n)        means    ($.==m .. $.==n)    in list context only
+    my $e = shift;
+    for (my $i=0; $i<@$e; $i++) {
+        next unless ref($e->[$i]) eq 'PPI::Token::Operator' 
+            && $e->[$i] eq '...';
+
+        # token before the ... operator
+        my $j = $i - 1;
+        $j-- while $j>0 && ref($e->[$j]) eq 'PPI::Token::Whitespace';
+
+        if ($j >= 0 && ref($e->[$j]) eq 'PPI::Token::Number') {
+            if ($j==0) {
+                unshift @$e,
+                  bless({content => '$.'}, 'PPI::Token::Magic'),
+                  bless({content => '=='}, 'PPI::Token::Operator');
+                last;
+            } else {
+                splice @$e, $j, 0,
+                  bless({content => '$.'}, 'PPI::Token::Magic'),
+                  bless({content => '=='}, 'PPI::Token::Operator');
+                last;
+                # how to tell if Number represents a standalone expression?
+                # or a numerical expression like + 40
+            }
+        }
+        # token after the ... operator
+        $j = $i + 1;
+        $j++ while $j<@$e && ref($e->[$j]) eq 'PPI::Token::Whitespace';
+        if ($j < @$e && (ref($e->[$j]) eq 'PPI::Token::Number' ||
+                         ref($e->[$j]) eq 'PPI::Token::Number::Float')) {
+            if ($j == $#$e) {
+                splice @$e, $j, 0,
+                bless({content => '$.'}, 'PPI::Token::Magic'),
+                bless({content => '=='}, 'PPI::Token::Operator');
+            }
+        }
+    }
+    return;
+}
+
 sub __append_implicit_to_naked_shift_pop {
     #
     # look for use of implicit @_/@ARGV with shift/pop.
@@ -823,9 +957,9 @@ sub __add_implicit_to_given_when_blocks {
     #         analyze PPI::Structure::When element
     #             if there is an "implicit smart match",
     #             insert  << $_ ~~ >>  at the beginning of the struct
-    my $given_child = $given->find('PPI::Structure::Given') or next;
+    my $given_child = $given->find('PPI::Structure::Given') or return;
     my $given_expr 
-	= $given_child->[0]->find('PPI::Statement::Expression') or next;
+	= $given_child->[0]->find('PPI::Statement::Expression') or return;
 
     my $given_tok = join '', $given_expr->[0]->tokens;
 
@@ -945,7 +1079,7 @@ sub __add_implicit_to_given_when_blocks {
 #
 sub __decorate_first_statement_in_for_block {
 
-    # We expect a particular pattern of PPI code to describe the
+    # We expect a particular pattern of PPI elements to describe the
     # "first statement in the block of a C-style for-loop":
     #
     # PPI::Statement::Compound                     $gparent
@@ -1010,7 +1144,8 @@ sub __decorate_first_statement_in_for_block {
 }
 
 sub __decorate_first_statement_in_foreach_block {
-    # Description of "first statement in block of a foreach loop"
+    # We expect a particular pattern of PPI elements to describe the
+    # "first statement in block of a foreach loop"
     #
     #PPI::Statement::Compound                      $gparent
     #  PPI::Token::Word       for/foreach
@@ -1068,12 +1203,12 @@ sub __decorate_first_statement_in_foreach_block {
 }
 
 sub __decorate_first_statement_in_while_block {
-    # We expect a particular pattern of PPI code to describe the
-    # "first statement in the block of a C-style for-loop":
+    # We expect a particular pattern of PPI elements to describe the
+    # "first statement in a while/until block"
     #
     # PPI::Statement::Compound                     $gparent
     #   PPI::Token::Word (while/until)
-    #   zero of more PPI::Token::Whitespace
+    #   zero or more PPI::Token::Whitespace
     #   PPI::Structure::Condition                  $cond
     #     ...
     #   zero or more PPI::Token::Whitespace
@@ -1237,7 +1372,7 @@ sub __new_token {
 }
 
 our $NULL_DOC = '';
-our $NULL_STATEMENT;
+our $NULL_STATEMENT;     # for empty clause in for(...; ...; ...) statement
 sub __new_null_statement {
     unless ($NULL_STATEMENT) {
 	$NULL_DOC = PPI::Document->new(\' ');           #' \');
@@ -1246,6 +1381,28 @@ sub __new_null_statement {
     return $NULL_STATEMENT->clone();
 }
 
+sub main::TEST {
+    # invoke with  perl -MDevel::DumpTrace::PPI -e TEST file
+    open(my $fh, '<', $ARGV[0])  or die;
+    my $all_code = join '', <$fh>;
+    close $fh;
+    my $doc = PPI::Document->new(\$all_code);
+    $doc->index_locations;
+    my $ss = $doc->find('PPI::Statement');
+    foreach my $i (0 .. $#$ss) {
+        my $s = $ss->[$i];
+        my @e = $s->elements;
+        for my $j (0 .. $#e) {
+            my $w = "$e[$j]";
+            $w =~ s/^\s+//;
+            $w =~ s/\s+$//;
+            my $ref = ref($e[$j]);
+            $ref =~ s/PPI:://;
+            printf "%d:%d\t%-20s\t%s\n", $i, $j, $ref, $w;
+        }
+    }
+}
+
 1;
 
 __END__
@@ -1256,7 +1413,7 @@ Devel::DumpTrace::PPI - PPI-based version of Devel::DumpTrace
 
 =head1 VERSION
 
-0.18
+0.19
 
 =head1 SYNOPSIS
 
@@ -1381,7 +1538,7 @@ expressions
     ----------------------------------------------
     3       4       5
 
-=item * Can insert implicitly used C<$_>, C<@_>, C<@ARGV> variables
+=item * Can insert implicit C<$_>, C<@_>, C<$.>, C<@ARGV> variables
 
 C<$_> is often used as the implicit target of regular expressions
 or an implicit argument to many standard functions. Since Perl v5.10,
@@ -1406,6 +1563,47 @@ in the trace output.
     0>>>>>           print 'hello'=~m/hello/ && sin 'hello'
     -------------------------------------------
 
+Since v0.13 there is limited support for inserting the
+implicit smartmatch (C<~~>) operations in a C<given/when>
+construction.
+
+Since v0.19 this feature includes the implicit assignment to C<$_>
+in a C<< while (<HANDLE>) >> or C<< until (<HANDLE>) >>
+construction.
+
+Since v0.19 this feature includes limited support for the
+implicit L<< C<$.> |perlvar/"NR" >> comparison with the three-dot
+L<< flip-flop operator|perlop/"Range-Operators" >> C<...>.
+
+=item * Smarter abbreviation of large arrays and hashes
+
+When displaying the contents of a large array or hash table,
+C<Devel::DumpTrace> can abbreviate the output.
+
+When displaying the contents of an array or hash table,
+the PPI-based parser can sometimes evaluate the expressions
+inside subscripts. When the array or hash is large and
+abbreviated output is used, the abbreviation can use the
+value of the subscript expression to provide better context.
+
+    $ perl -d:DumpTrace::noPPI=quiet -e '@r=(0..99);' -e '$s=$r[50];'
+    >>>>> -e:1:[__top__]:   @r:(0,1,2,3,4,5,6,7,...)=(0..99);
+    >>>>> -e:2:[__top__]:   $s:50=$r:(0,1,2,3,4,5,6,7,...)[50];
+
+In some cases, the PPI-based parser can evaluate the expressions inside
+subscripts. This value can be used to produce an abbreviation with
+some context:
+
+    $ perl -Ilib -d:DumpTrace::PPI=quiet -e '@r=(0..99);' -e '$s=$r[50];'
+    >>>>> -e:1:[__top__]:   @r:(0,1,2,3,4,5,6,7,...)=(0..99);
+    >>>>> -e:2:[__top__]:   $s:50=$r:(0,1,2,...,50,...,99)[50];
+
+For some complex cases (like programs with C<tie>'d variables where just
+reading a variable's value can have side effects) you may want to 
+disable the context-sensitive abbreviation of large arrays and hashes.
+This can be done by passing a true value in the environment variable
+C<DUMPTRACE_DUMB_ABBREV>. 
+
 =back
 
 The PPI-based parser has more overhead than the simpler parser from
@@ -1439,11 +1637,11 @@ typically appears only once, during the first iteration of the loop:
     >> -e:2: $j = $i ** 2;
     >> -e:2: $j = $i ** 2;
 
-Perl is supposed to be evaluating the expressions C<$i++> and C<< $i<3 >>
+Perl still evaluates the expressions C<$i++> and C<< $i<3 >>
 at each iteration, but those steps are optimized out of the trace output.
 
 Or for another example, a trace through a complex C<if-elsif-else>
-structure only produces the condition expression for the initial
+structure may only produce the conditional expression for the initial
 C<if> statement:
 
     $ perl -d:Trace -e '$a=3;
@@ -1546,31 +1744,31 @@ value of the loop variable at the beginning of each iteration.
 
     $ perl -d:DumpTrace::PPI -e '
     for (1 .. 6) {
-    $n += 2 * $_ - 1;
-    print $_, "\t", $n, "\n"
+      $n += 2 * $_ - 1;
+      print $_, "\t", $n, "\n"
     }
     '
     >>>>> -e:2:[__top__]:   for $_:1 (1 .. 6) {
-    >>>>> -e:3:[__top__]:   $n:1 += 2 * $_:1 - 1;
-    >>>   -e:4:[__top__]:   print $_:1, "\t", $n:1, "\n"
+    >>>>> -e:3:[__top__]:     $n:1 += 2 * $_:1 - 1;
+    >>>   -e:4:[__top__]:     print $_:1, "\t", $n:1, "\n"
     1       1
     >>>>> -e:3:[__top__]:   FOREACH: {$_:2}         $n:4 += 2 * $_:2 - 1;
-    >>>   -e:4:[__top__]:   print $_:2, "\t", $n:4, "\n"
+    >>>   -e:4:[__top__]:     print $_:2, "\t", $n:4, "\n"
     2       4
     >>>>> -e:3:[__top__]:   FOREACH: {$_:3}         $n:9 += 2 * $_:3 - 1;
-    >>>   -e:4:[__top__]:   print $_:3, "\t", $n:9, "\n"
+    >>>   -e:4:[__top__]:     print $_:3, "\t", $n:9, "\n"
     3       9
     >>>>> -e:3:[__top__]:   FOREACH: {$_:4}         $n:16 += 2 * $_:4 - 1;
-    >>>   -e:4:[__top__]:   print $_:4, "\t", $n:16, "\n"
+    >>>   -e:4:[__top__]:     print $_:4, "\t", $n:16, "\n"
     4       16
     >>>>> -e:3:[__top__]:   FOREACH: {$_:5}         $n:25 += 2 * $_:5 - 1;
-    >>>   -e:4:[__top__]:   print $_:5, "\t", $n:25, "\n"
+    >>>   -e:4:[__top__]:     print $_:5, "\t", $n:25, "\n"
     5       25
     >>>>> -e:3:[__top__]:   FOREACH: {$_:6}         $n:36 += 2 * $_:6 - 1;
-    >>>   -e:4:[__top__]:   print $_:6, "\t", $n:36, "\n"
+    >>>   -e:4:[__top__]:     print $_:6, "\t", $n:36, "\n"
     6       36
 
-=head2 Special handle for while/until loops
+=head2 Special handling for while/until loops
 
 As with a C<for> loop, the conditional expression of a 
 C<while> or C<until> loop is only included in trace output
@@ -1738,58 +1936,45 @@ In this example, the C<ELSEIF> (I<expression>) and C<ELSE> decorators
 indicate what expressions must have been evaluated to reach
 the particular block of the statement that is to be executed.
 
-=head2 Some TODOs
+=head1 Some TODOs
 
-Other flow control structures in Perl could benefit from 
-similar treatment. These will be addressed in future versions
-of this distribution.
+With the L<range operators|perlop/"Range-Operators"> 
+C<..> and C<...>, an argument that is a
+constant expression is implicitly compared against the magic
+variable L<< C<$.> |perlop/"NR" >>.
 
-=over 4
+For B<the limited cases> of the three-dot range operator (C<...>)
+and a numeric argument, this module can prepent C<$. ==> to an
+argument to allow you to see the value of C<$.> being used.
 
-=item C<do-while> and C<do-until> loops
+    $ seq 1 10 | perl -d:DumpTrace::PPI -ne 'print if 4 ... 6'
+    >>>   -e:0:[__top__]:
+    >>>   -e:1:[__top__]:   print if $.:1==4 ... 6
+    >>>   -e:1:[__top__]:   print if $.:2==4 ... 6
+    >>>   -e:1:[__top__]:   print if $.:3==4 ... 6
+    >>>   -e:1:[__top__]:   print if $.:4==4 ... 6
+    4
+    >>>   -e:1:[__top__]:   print if $.:5==4 ... 6
+    5
+    >>>   -e:1:[__top__]:   print if $.:6==4 ... 6
+    6
+    >>>   -e:1:[__top__]:   print if $.:7==4 ... 6
+    >>>   -e:1:[__top__]:   print if $.:8==4 ... 6
+    >>>   -e:1:[__top__]:   print if $.:9==4 ... 6
+    >>>   -e:1:[__top__]:   print if $.:10==4 ... 6
 
-=item C<for[each]> [variable] LIST loops
+The two-dot C<..> flip-flop operator looks the same as the
+(list context) range operator, and it is tricky for this parser
+to distinguish the two uses:
 
-=item C<map BLOCK LIST> and C<grep BLOCK LIST> blocks
+    for (10..20) { ... }    # range operator, no implicit $.
+    if  (10..20) { ... }    # flip-flop operator, implicit $. compar
 
-=item postfix C<EXPR for LIST>, C<EXPR while/until CONDITION> statements
-
-Postfix expressions are typically executed as a single operation
-(with no place to hold a breakpoint). This item might need some L<B-fu|B>.
+Adding the implicit C<$.> omparison with the two-dot flip-flop
+operator will have to be done in a future release.
 
 =back
 
-=head1 OTHER FEATURES
-
-=head2 "Smart" abbreviation of large arrays and hashes
-
-When displaying the contents of a large array or hash table,
-C<Devel::DumpTrace> can abbreviate the output.
-
-When displaying the contents of an array or hash table,
-the PPI-based parser can sometimes evaluate the expressions
-inside subscripts. When the array or hash is large and
-abbreviated output is used, the abbreviation can use the
-value of the subscript expression to provide better context.
-
-    $ perl -d:DumpTrace::noPPI=quiet -e '@r=(0..99);' -e '$s=$r[50];'
-    >>>>> -e:1:[__top__]:   @r:(0,1,2,3,4,5,6,7,...)=(0..99);
-    >>>>> -e:2:[__top__]:   $s:50=$r:(0,1,2,3,4,5,6,7,...)[50];
-
-In some cases, the PPI-based parser can evaluate the expressions inside
-subscripts. This value can be used to produce an abbreviation with
-some context:
-
-    $ perl -Ilib -d:DumpTrace::PPI=quiet -e '@r=(0..99);' -e '$s=$r[50];'
-    >>>>> -e:1:[__top__]:   @r:(0,1,2,3,4,5,6,7,...)=(0..99);
-    >>>>> -e:2:[__top__]:   $s:50=$r:(0,1,2,...,50,...,99)[50];
-
-For some complex cases (like programs with C<tie>'d variables where just
-reading a variable's value can have side effects) you may want to 
-disable the context-sensitive abbreviation of large arrays and hashes.
-This can be done by passing a true value in the environment variable
-C<DUMPTRACE_DUMB_ABBREV>. 
-
 =head1 SUBROUTINES/METHODS
 
 None to worry about.
@@ -1800,7 +1985,7 @@ Nothing is or can be exported from this module.
 
 =head1 DIAGNOSTICS
 
-None
+All output from this module is for diagnostics.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
@@ -1839,7 +2024,7 @@ Marty O'Brien, E<lt>mob at cpan.orgE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2012 Marty O'Brien.
+Copyright 2010-2015 Marty O'Brien.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
